<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.ui" line="+14"/>
        <source>About Transmission</source>
        <translation>Tietoa Transmissionista</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Copyright © The Transmission Project</source>
        <translation>Copyright © Transmission-projekti</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>A fast and easy BitTorrent client</source>
        <translation>Nopea ja helppo BitTorrent-asiakasohjelma</translation>
    </message>
    <message>
        <location filename="../AboutDialog.cc" line="+37"/>
        <source>Client</source>
        <translation>Asiakasohjelmisto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Server</source>
        <translation>Palvelin</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>C&amp;redits</source>
        <translation>L&amp;opputekstit</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;License</source>
        <translation>&amp;Lisenssi</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Credits</source>
        <translation>Lopputekstit</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../Application.cc" line="+332"/>
        <source>&lt;b&gt;Transmission is a file sharing program.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Transmission on ohjelma tiedostojen jakamiseen.&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>When you run a torrent, its data will be made available to others by means of upload. Any content you share is your sole responsibility.</source>
        <translation>Kun käytät torrenttia, sen data lähetetään muille käyttäjille. Kaiken sisällön jakaminen tapahtuu omalla vastuullasi.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>I &amp;Agree</source>
        <translation>H&amp;yväksyn</translation>
    </message>
    <message numerus="yes">
        <location line="+110"/>
        <source>Torrent(s) Completed</source>
        <translation>
            <numerusform>Torrenti valmistui</numerusform>
            <numerusform>Torrentit valmistuivat</numerusform>
        </translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Torrent Added</source>
        <translation>Torrent lisätty</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../DetailsDialog.cc" line="+432"/>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mixed</source>
        <translation>Sekoitettu</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+267"/>
        <source>Unknown</source>
        <translation>Tunnistamaton</translation>
    </message>
    <message>
        <location line="-210"/>
        <source>Finished</source>
        <translation>Valmistunut</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>Tauotettu</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>%1 (+%2 discarded after failed checksum)</source>
        <translation>%1 (+%2 hylätty väärän tarkistussumman jälkeen)</translation>
    </message>
    <message>
        <location line="+135"/>
        <source>Active now</source>
        <translation>Nyt aktiivisena</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 ago</source>
        <translation>%1 sitten</translation>
    </message>
    <message numerus="yes">
        <location line="+63"/>
        <source>%1 (%Ln pieces @ %2)</source>
        <translation>
            <numerusform>%1 (%Ln osa @ %2)</numerusform>
            <numerusform>%1 (%Ln osaa @ %2)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%1 (%Ln pieces)</source>
        <translation>
            <numerusform>%1 (%Ln osa)</numerusform>
            <numerusform>%1 (%Ln osaa)</numerusform>
        </translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Private to this tracker -- DHT and PEX disabled</source>
        <translation>Yksityisesti tälle seurantapalvelimelle -- DHT ja PEX pois käytöstä</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Public torrent</source>
        <translation>Julkinen torrent</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Created by %1</source>
        <translation>Luonut %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created on %1</source>
        <translation>Luotu %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created by %1 on %2</source>
        <translation>Luonut %1 ajankohtana %2</translation>
    </message>
    <message>
        <location line="+204"/>
        <location line="+47"/>
        <source>Encrypted connection</source>
        <translation>Salattu yhteys</translation>
    </message>
    <message>
        <location line="-28"/>
        <source>Optimistic unchoke</source>
        <translation>Optimistinen rajoituksen poisto</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading from this peer</source>
        <translation>Ladataan tältä vertaiselta</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would download from this peer if they would let us</source>
        <translation>Voitaisiin ladata tältä vertaiselta mikäli he sallisivat sen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Uploading to peer</source>
        <translation>Lähetetään vertaiselle</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would upload to this peer if they asked</source>
        <translation>Voitaisiin lähettää tälle vertaiselle mikäli he pyytäisivät</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer has unchoked us, but we&apos;re not interested</source>
        <translation>Vertainen ei rajoita meitä, mutta emme ole kiinnostuneita</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We unchoked this peer, but they&apos;re not interested</source>
        <translation>Emme rajoita tätä vertaista, mutta he eivät ole kiinnostuneita</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer was discovered through DHT</source>
        <translation>Vertainen löydettiin DHT:n välityksellä</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer was discovered through Peer Exchange (PEX)</source>
        <translation>Vertainen löydettiin Peer Exchangen (PEX) välityksellä</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is an incoming connection</source>
        <translation>Vertainen on sisääntuleva yhteys</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is connected over µTP</source>
        <translation>Vertainen on µTP:n kautta yhteydessä</translation>
    </message>
    <message numerus="yes">
        <location line="+130"/>
        <source> minute(s)</source>
        <extracomment>Spin box suffix, &quot;Stop seeding if idle for: [ 5 minutes ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform>minuutti</numerusform>
            <numerusform>minuuttia</numerusform>
        </translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Add tracker announce URLs, one per line:</source>
        <translation>Lisää jäljitin ilmoittamaan URL-osoitteet, yksi riviä kohti:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No new URLs found.</source>
        <translation>Uusia URL-osoitteita ei löytynyt.</translation>
    </message>
    <message>
        <location line="-843"/>
        <source>%1 (100%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data</extracomment>
        <translation>%1 (100%)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data, %2 is overall size of torrent data, %3 is percentage (%1/%2*100)</extracomment>
        <translation>%1 / %2 (%3%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%), %4 Unverified</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded data (both verified and unverified), %2 is overall size of torrent data, %3 is percentage (%1/%2*100), %4 is amount of downloaded but not yet verified data</extracomment>
        <translation>%1 / %2 (%3%), %4 vahvistamatonta</translation>
    </message>
    <message>
        <location line="+70"/>
        <source>%1 (Ratio: %2)</source>
        <translation>%1 (Suhde: %2)</translation>
    </message>
    <message>
        <location line="+273"/>
        <location line="+55"/>
        <source>N/A</source>
        <translation>Ei saatavilla</translation>
    </message>
    <message>
        <location line="+390"/>
        <source>Add URL(s)</source>
        <translation>Lisää yksi tai useampi URL-osoite</translation>
    </message>
    <message>
        <location line="+112"/>
        <source>High</source>
        <translation>Korkea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Matala</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+4"/>
        <source>Use Global Settings</source>
        <translation>Käytä yleisiä asetuksia</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Seed regardless of ratio</source>
        <translation>Kylvä suhdeluvusta huolimatta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding at ratio:</source>
        <translation>Pysäytä kylväminen suhdeluvulla:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Seed regardless of activity</source>
        <translation>Kylvä aktiivisuudesta huolimatta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding if idle for:</source>
        <translation>Pysäytä kylväminen jos joutilaana ajan:</translation>
    </message>
    <message>
        <location line="+75"/>
        <source>Up</source>
        <translation>Ylös</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Down</source>
        <translation>Alas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status</source>
        <translation>Tila</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Address</source>
        <translation>Osoite</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Client</source>
        <translation>Asiakasohjelma</translation>
    </message>
    <message>
        <location filename="../DetailsDialog.ui" line="+14"/>
        <source>Torrent Properties</source>
        <translation>Torrentin ominaisuudet</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Information</source>
        <translation>Tietoa</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Activity</source>
        <translation>Aktiviteetti</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Have:</source>
        <translation>Hallussa:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Availability:</source>
        <translation>Saatavuus:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Uploaded:</source>
        <translation>Lähetetty:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Downloaded:</source>
        <translation>Ladattu:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>State:</source>
        <translation>Tila:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Running time:</source>
        <translation>Kulunut aika:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Remaining time:</source>
        <translation>Aikaa jäljellä:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Last activity:</source>
        <translation>Aktiivinen viimeksi:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Error:</source>
        <translation>Virhe:</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Details</source>
        <translation>Lisätiedot</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Size:</source>
        <translation>Koko:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Location:</source>
        <translation>Sijainti:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Edit Trackers</source>
        <translation>Muokkaa seurantapalvelimia</translation>
    </message>
    <message>
        <location line="-190"/>
        <source>Hash:</source>
        <translation>Tarkiste:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Privacy:</source>
        <translation>Yksityisyys:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Origin:</source>
        <translation>Lähde:</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Added:</source>
        <translation>Lisätty:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Comment:</source>
        <translation>Kommentti:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Peers</source>
        <translation>Vertaiset</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tracker</source>
        <translation>Seurantapalvelin</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add Tracker</source>
        <translation>Lisää seurantapalvelin</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Remove Trackers</source>
        <translation>Poista seurantapalvelimia</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Show &amp;more details</source>
        <translation>Näytä &amp;lisää tietoja</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show &amp;backup trackers</source>
        <translation>Näytä &amp;varalla olevat seurantapalvelimet</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Files</source>
        <translation>Tiedostot</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Options</source>
        <translation>Ominaisuudet</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Speed</source>
        <translation>Nopeus</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Honor global &amp;limits</source>
        <translation>Kunnioita yleisiä &amp;rajoituksia</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Limit &amp;download speed:</source>
        <translation>Rajoita &amp;latausnopeutta:</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>Limit &amp;upload speed:</source>
        <translation>Rajoita &amp;lähetysnopeutta:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Torrent &amp;priority:</source>
        <translation>Torrentin &amp;tärkeysjärjestys:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Seeding Limits</source>
        <translation>Rajoitukset kylvämiselle</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Ratio:</source>
        <translation>&amp;Suhde:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Idle:</source>
        <translation>&amp;Joutilaana:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Peer Connections</source>
        <translation>Vertaisen yhteydet</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Maximum peers:</source>
        <translation>&amp;Vertaisia enimmillään:</translation>
    </message>
</context>
<context>
    <name>FileTreeItem</name>
    <message>
        <location filename="../FileTreeItem.cc" line="+297"/>
        <location filename="../FileTreeView.cc" line="+108"/>
        <location line="+254"/>
        <source>Low</source>
        <translation>Matala</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-254"/>
        <location line="+252"/>
        <source>High</source>
        <translation>Korkea</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-252"/>
        <location line="+253"/>
        <source>Normal</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-252"/>
        <source>Mixed</source>
        <translation>Sekoitettu</translation>
    </message>
</context>
<context>
    <name>FileTreeModel</name>
    <message>
        <location filename="../FileTreeModel.cc" line="+195"/>
        <source>File</source>
        <translation>Tiedosto</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Progress</source>
        <translation>Tilanne</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Download</source>
        <translation>Lataa</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Priority</source>
        <translation>Tärkeysjärjestys</translation>
    </message>
</context>
<context>
    <name>FileTreeView</name>
    <message>
        <location filename="../FileTreeView.cc" line="+244"/>
        <source>Check Selected</source>
        <translation>Merkkaa valitut</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uncheck Selected</source>
        <translation>Poista valittujen merkintä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Only Check Selected</source>
        <translation>Merkkaa vain valitut</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Priority</source>
        <translation>Tärkeysjärjestys</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rename…</source>
        <translation>Nimeä uudelleen…</translation>
    </message>
</context>
<context>
    <name>FilterBar</name>
    <message>
        <location filename="../FilterBar.cc" line="+48"/>
        <location line="+145"/>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <location line="-136"/>
        <source>Active</source>
        <translation>Aktiivinen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading</source>
        <translation>Ladataan</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Seeding</source>
        <translation>Kylvätään</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>Tauotettu</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Finished</source>
        <translation>Valmistunut</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Verifying</source>
        <translation>Vahvistetaan</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location line="+140"/>
        <source>Show:</source>
        <translation>Näytä:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Search…</source>
        <translation>Etsi…</translation>
    </message>
</context>
<context>
    <name>Formatter</name>
    <message>
        <location filename="../Formatter.cc" line="+24"/>
        <source>B/s</source>
        <translation>t/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>kB/s</source>
        <translation>Kt/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MB/s</source>
        <translation>Mt/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GB/s</source>
        <translation>Gt/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TB/s</source>
        <translation>Tt/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>B</source>
        <translation>t</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>kB</source>
        <translation>Kt</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MB</source>
        <translation>Mt</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GB</source>
        <translation>Gt</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TB</source>
        <translation>Tt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location line="+37"/>
        <location line="+25"/>
        <source>Unknown</source>
        <translation>Tuntematon</translation>
    </message>
    <message>
        <location line="-20"/>
        <location line="+10"/>
        <source>None</source>
        <translation>Ei yhtään</translation>
    </message>
    <message>
        <location filename="../Formatter.h" line="+64"/>
        <location line="+7"/>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
    <message numerus="yes">
        <location filename="../Formatter.cc" line="+41"/>
        <source>%Ln day(s)</source>
        <translation>
            <numerusform>%Ln päivä</numerusform>
            <numerusform>%Ln päivää</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-5"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%Ln tunti</numerusform>
            <numerusform>%Ln tuntia</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuutti</numerusform>
            <numerusform>%Ln minuuttia</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln second(s)</source>
        <translation>
            <numerusform>%Ln sekunti</numerusform>
            <numerusform>%Ln sekuntia</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FreeSpaceLabel</name>
    <message>
        <location filename="../FreeSpaceLabel.cc" line="+52"/>
        <source>&lt;i&gt;Calculating Free Space…&lt;/i&gt;</source>
        <translation>&lt;i&gt;Lasketaan vapaata tilaa…&lt;/i&gt;</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>%1 free</source>
        <translation>%1 vapaana</translation>
    </message>
</context>
<context>
    <name>LicenseDialog</name>
    <message>
        <location filename="../LicenseDialog.ui" line="+14"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.ui" line="+14"/>
        <source>Transmission</source>
        <translation>Transmission</translation>
    </message>
    <message>
        <location line="+181"/>
        <source>&amp;Torrent</source>
        <translation>&amp;Torrent</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Help</source>
        <translation>&amp;Ohje</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;View</source>
        <translation>&amp;Näytä</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Create a new torrent</source>
        <translation>Luo uusi torrent</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Properties</source>
        <translation>&amp;Ominaisuudet</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Show torrent properties</source>
        <translation>Näytä torrentin ominaisuudet</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open the torrent&apos;s folder</source>
        <translation>Avaa torrentin hakemisto</translation>
    </message>
    <message>
        <location line="-161"/>
        <source>Queue</source>
        <translation>Jonota</translation>
    </message>
    <message>
        <location line="-132"/>
        <source>Options</source>
        <translation>Valinnat</translation>
    </message>
    <message>
        <location line="+83"/>
        <source>Statistics</source>
        <translation>Tilastot</translation>
    </message>
    <message>
        <location line="+171"/>
        <source>&amp;Open…</source>
        <translation>&amp;Avaa…</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open a torrent</source>
        <translation>Avaa torrent</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;New…</source>
        <translation>&amp;Uusi…</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Open Fold&amp;er</source>
        <translation>Avaa hake&amp;misto</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Start</source>
        <translation>&amp;Aloita</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start torrent</source>
        <translation>Aloita torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ask Tracker for &amp;More Peers</source>
        <translation>Pyydä seurantapalvelimelta &amp;lisää vertaisia</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ask tracker for more peers</source>
        <translation>Pyydä seurantapalvelimelta lisää vertaisia</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause</source>
        <translation>&amp;Tauko</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Pause torrent</source>
        <translation>Tauota torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Verify Local Data</source>
        <translation>&amp;Vahvista paikallinen data</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Verify local data</source>
        <translation>Vahvista paikallinen data</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent</source>
        <translation>Poista torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Delete Files and Remove</source>
        <translation>&amp;Poista tiedostot ja latauslistasta</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent and delete its files</source>
        <translation>Poista torrent ja poista sen tiedostot</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Start All</source>
        <translation>&amp;Aloita kaikki</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause All</source>
        <translation>&amp;Tauota kaikki</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Quit</source>
        <translation>&amp;Poistu</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Select All</source>
        <translation>&amp;Valitse kaikki</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Deselect All</source>
        <translation>&amp;Poista kaikki valinnat</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Asetukset</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Compact View</source>
        <translation>&amp;Kompakti näkymä</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+3"/>
        <source>Compact View</source>
        <translation>Kompakti näkymä</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Toolbar</source>
        <translation>&amp;Työkalupalkki</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Filterbar</source>
        <translation>&amp;Suodatinpalkki</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statusbar</source>
        <translation>&amp;Tilannepalkki</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Activity</source>
        <translation>Järjestä &amp;aktiivisuuden mukaan</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by A&amp;ge</source>
        <translation>Järjestä i%än mukaan</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Time &amp;Left</source>
        <translation>Järjestä jäljellä olevan ajan &amp;mukaan</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Name</source>
        <translation>Järjestä nimen &amp;mukaan</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Progress</source>
        <translation>Järjestä tilanteen &amp;mukaan</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Rati&amp;o</source>
        <translation>Järjestä suhteen mukaa&amp;n</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Si&amp;ze</source>
        <translation>Järjestä koon muka&amp;an</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Stat&amp;e</source>
        <translation>Järjestä tilan mukaa&amp;n</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by T&amp;racker</source>
        <translation>Järjestä seurantapalvelimien m&amp;ukaan</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Message &amp;Log</source>
        <translation>Viesti&amp;loki</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statistics</source>
        <translation>&amp;Tilastotiedot</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Contents</source>
        <translation>&amp;Sisältö</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Re&amp;verse Sort Order</source>
        <translation>Kä&amp;ännä lajittelujärjestystä</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Name</source>
        <translation>&amp;Nimi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Files</source>
        <translation>&amp;Tiedostot</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Tracker</source>
        <translation>&amp;Seurantapalvelin</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Ratio</source>
        <translation>Suhde kaikkiaan</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Ratio</source>
        <translation>Istunnon suhde</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Transfer</source>
        <translation>Siirretty kaikkiaan</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Transfer</source>
        <translation>Istunnon siirrot</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Main Window</source>
        <translation>&amp;Pääikkuna</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tray &amp;Icon</source>
        <translation>&amp;Ilmoitusalueen kuvake</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Change Session…</source>
        <translation>&amp;Vaihda istuntoa…</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Set &amp;Location…</source>
        <translation>Aseta &amp;sijainti…</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Open &amp;URL…</source>
        <translation>Avaa &amp;URL-osoite…</translation>
    </message>
    <message>
        <location line="-15"/>
        <source>Choose Session</source>
        <extracomment>Start a local session or connect to a running session</extracomment>
        <translation>Valitse istunto</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Copy Magnet Link to Clipboard</source>
        <translation>&amp;Kopioi Magnet-linkki leikepöydälle</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Donate</source>
        <translation>&amp;Lahjoita</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start &amp;Now</source>
        <translation>Aloita &amp;nyt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Bypass the queue and start now</source>
        <translation>Ohita jonotus ja aloita nyt</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Move to &amp;Top</source>
        <translation>Siirrä &amp;ylimmäiseksi</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Move &amp;Up</source>
        <translation>Siirrä &amp;ylös</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move &amp;Down</source>
        <translation>Siirrä &amp;alas</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move to &amp;Bottom</source>
        <translation>Siirrä %alimmaiseksi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Queue</source>
        <translation>Järjestä jonotuksen &amp;mukaan</translation>
    </message>
    <message>
        <location filename="../MainWindow.cc" line="+468"/>
        <source>Limit Download Speed</source>
        <translation>Rajoita latausnopeutta</translation>
    </message>
    <message>
        <location line="-55"/>
        <source>Unlimited</source>
        <translation>Rajoittamaton</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+752"/>
        <location line="+9"/>
        <source>Limited at %1</source>
        <translation>Rajoitettu nopeudelle %1</translation>
    </message>
    <message>
        <location line="-706"/>
        <source>Limit Upload Speed</source>
        <translation>Rajoita lähetysnopeutta</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Stop Seeding at Ratio</source>
        <translation>Lopeta kylväminen suhdeluvulla</translation>
    </message>
    <message>
        <location line="-40"/>
        <source>Seed Forever</source>
        <translation>Kylvä ikuisesti</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+739"/>
        <source>Stop at Ratio (%1)</source>
        <translation>Pysäytä suhdeluvulla (%1)</translation>
    </message>
    <message>
        <location line="-393"/>
        <source> - %1:%2</source>
        <extracomment>Second (optional) part of main window title &quot;Transmission - host:port&quot; (added when connected to remote session) notice that leading space (before the dash) is included here</extracomment>
        <translation>- %1:%2</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Idle</source>
        <translation>Joutilaana</translation>
    </message>
    <message>
        <location line="+30"/>
        <location line="+15"/>
        <source>Ratio: %1</source>
        <translation>Suhdeluku: %1</translation>
    </message>
    <message>
        <location line="-10"/>
        <location line="+5"/>
        <source>Down: %1, Up: %2</source>
        <translation>Alas: %1, Ylös: %2</translation>
    </message>
    <message>
        <location line="+424"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Torrent-tiedostot (*.torrent);;Kaikki tiedostot (*.*)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show &amp;options dialog</source>
        <translation>Näytä &amp;valintaikkuna</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Open Torrent</source>
        <translation>Avaa torrent</translation>
    </message>
    <message>
        <location line="-1003"/>
        <source>Speed Limits</source>
        <translation>Nopeusrajoitukset</translation>
    </message>
    <message>
        <location line="+537"/>
        <source>Network Error</source>
        <translation>Verkkovirhe</translation>
    </message>
    <message>
        <location line="+434"/>
        <source>Click to disable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>Napsauta poistaaksesi käytöstä vaihtoehtoiset nopeusrajoitukset
 (%1 lataus, %2 lähetys)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Click to enable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>Napsauta käyttääksesi vaihtoehtoisia nopeusrajoituksia
 (%1 lataus, %2 lähetys)</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Remove torrent?</source>
        <translation>Poistetaanko torrent?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Delete this torrent&apos;s downloaded files?</source>
        <translation>Poistetaanko tämän torrentin ladatut tiedostot?</translation>
    </message>
    <message numerus="yes">
        <location line="-4"/>
        <source>Remove %Ln torrent(s)?</source>
        <translation>
            <numerusform>Poista %Ln torrentti?</numerusform>
            <numerusform>Poista %Ln torrenttia?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-505"/>
        <source>Showing %L1 of %Ln torrent(s)</source>
        <translation>
            <numerusform>Näytetään %L1/%Ln torrentista</numerusform>
            <numerusform>Näytetään %L1/%Ln torrentista</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+510"/>
        <source>Delete these %Ln torrent(s)&apos; downloaded files?</source>
        <translation>
            <numerusform>Poistetaanko tämän torrentin ladatut tiedostot?</numerusform>
            <numerusform>Poista näiden %Ln:n torrentin ladatut tiedostot?</numerusform>
        </translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Once removed, continuing the transfer will require the torrent file or magnet link.</source>
        <translation>Kun poistettu, siirron jatkaminen vaatii torrent-tiedoston tai magneettilinkin.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Once removed, continuing the transfers will require the torrent files or magnet links.</source>
        <translation>Kun poistettu, siirtojen jatkaminen vaatii torrent-tiedostot tai magneettilinkit.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent has not finished downloading.</source>
        <translation>Tämä torrent ei ole vielä valmistunut lataamisessa.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>These torrents have not finished downloading.</source>
        <translation>Nämä torrentit eivät ole vielä valmistuneet lataamisessa.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent is connected to peers.</source>
        <translation>Tämä torrent on yhdistettynä vertaisiin.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>These torrents are connected to peers.</source>
        <translation>Nämä torrentit ovat yhdistetyttyinä vertaisiin.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>One of these torrents is connected to peers.</source>
        <translation>Jokin näistä torrenteista on yhteydessä vertaisiinsa.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents are connected to peers.</source>
        <translation>Jotkin näistä torrenteista ovat yhteydessä vertaisiinsa.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>One of these torrents has not finished downloading.</source>
        <translation>Jokin näistä torrenteista on vielä kesken.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents have not finished downloading.</source>
        <translation>Jotkin näistä torrenteista ovat vielä kesken.</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>%1 has not responded yet</source>
        <translation>%1 ei ole vielä vastannut</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 is responding</source>
        <translation>%1 vastaa</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 last responded %2 ago</source>
        <translation>%1 vastasi viimeksi %2 sitten</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 is not responding</source>
        <translation>%1 ei vastaa</translation>
    </message>
</context>
<context>
    <name>MakeDialog</name>
    <message>
        <location filename="../MakeDialog.ui" line="+17"/>
        <source>New Torrent</source>
        <translation>Uusi torrent</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="+304"/>
        <source>&lt;i&gt;No source selected&lt;/i&gt;</source>
        <translation>&lt;i&gt;Lähdettä ei ole valittu&lt;/i&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="+5"/>
        <source>%Ln File(s)</source>
        <translation>
            <numerusform>%Ln tiedosto</numerusform>
            <numerusform>%Ln tiedostoa</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln Piece(s)</source>
        <translation>
            <numerusform>%Ln osa</numerusform>
            <numerusform>%Ln osaa</numerusform>
        </translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 in %2; %3 @ %4</source>
        <translation>%1 kohteessa %2; %3 @ %4</translation>
    </message>
    <message>
        <location filename="../MakeDialog.ui" line="+9"/>
        <source>Files</source>
        <translation>Tiedostot</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Sa&amp;ve to:</source>
        <translation>Ta&amp;llenna kohteeseen:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Source f&amp;older:</source>
        <translation>Lähdeh&amp;akemisto:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Source &amp;file:</source>
        <translation>Lähde&amp;tiedosto:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Piece s&amp;ize:</source>
        <translation>Osan k&amp;oko:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Properties</source>
        <translation>Ominaisuudet</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Trackers:</source>
        <translation>&amp;Seurantapalvelimet:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>To add a backup URL, add it on the line after the primary URL.
To add another primary URL, add it after a blank line.</source>
        <translation>Jos haluat lisätä varmuuskopion verkko-osoitteen, lisää se riville ensisijaisen jälkeen.
Jos haluat lisätä toisen ensisijaisen verkko-osoitteen, lisää se tyhjän rivin jälkeen.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Co&amp;mment:</source>
        <translation>Ko&amp;mmentti:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Source:</source>
        <translation>&amp;Lähde:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Private torrent</source>
        <translation>&amp;Yksityinen torrent</translation>
    </message>
</context>
<context>
    <name>MakeProgressDialog</name>
    <message>
        <location filename="../MakeProgressDialog.ui" line="+14"/>
        <source>New Torrent</source>
        <translation>Uusi torrent</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="-184"/>
        <source>Creating &quot;%1&quot;</source>
        <translation>Luodaan &quot;%1&quot;</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Created &quot;%1&quot;!</source>
        <translation>&quot;%1&quot; luotu!</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Couldn&apos;t create &quot;%1&quot;: %2 (%3)</source>
        <translation>Ei voitu luoda &quot;%1&quot;: %2 (%3)</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../OptionsDialog.cc" line="+52"/>
        <source>Open Torrent</source>
        <translation>Avaa torrent</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Open Torrent from File</source>
        <translation>Avaa torrent tiedostosta</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open Torrent from URL or Magnet Link</source>
        <translation>Avaa torrent verkko-osoitteesta tai magneettilinkistä</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+17"/>
        <source>&amp;Source:</source>
        <translation>&amp;Lähde:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Destination folder:</source>
        <translation>&amp;Kohdekansio:</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="+49"/>
        <source>High</source>
        <translation>Korkea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Normaali</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Matala</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+35"/>
        <source>&amp;Priority:</source>
        <translation>&amp;Tärkeysjärjestys:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>S&amp;tart when added</source>
        <translation>A&amp;loita kun lisätty</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mo&amp;ve .torrent file to the trash</source>
        <translation>Si&amp;irrä .torrent-tiedosto roskakoriin</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="-40"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Torrent-tiedostot (*.torrent);;Kaikki tiedostot (*.*)</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Select Destination</source>
        <translation>Valitse kohde</translation>
    </message>
</context>
<context>
    <name>PathButton</name>
    <message>
        <location filename="../PathButton.cc" line="+23"/>
        <location line="+71"/>
        <source>(None)</source>
        <translation>(Ei yhtään)</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Select Folder</source>
        <translation>Valitse hakemisto</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Select File</source>
        <translation>Valitse tiedosto</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <location filename="../PrefsDialog.ui" line="+1223"/>
        <source>Use &amp;authentication</source>
        <translation>Käytä &amp;tunnistautumista</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Username:</source>
        <translation>&amp;Käyttäjänimi:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>Sala&amp;sana:</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>&amp;Open web client</source>
        <translation>&amp;Avaa web-asiakasohjelma</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Addresses:</source>
        <translation>Osoitteet:</translation>
    </message>
    <message>
        <location line="-1234"/>
        <source>Speed Limits</source>
        <translation>Nopeusrajoitukset</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>&lt;small&gt;Override normal speed limits manually or at scheduled times&lt;/small&gt;</source>
        <translation>&lt;small&gt;Korvaa normaalit nopeusrajoitukset käsin tai ajastettuina aikoina &lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>&amp;Scheduled times:</source>
        <translation>&amp;Määriteltyinä aikoina:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>&amp;On days:</source>
        <translation>&amp;Päivinä:</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+382"/>
        <source>Every Day</source>
        <translation>Joka päivä</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekdays</source>
        <translation>Arkipäivisin</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekends</source>
        <translation>Viikonloppuisin</translation>
    </message>
    <message>
        <location line="-238"/>
        <source>Sunday</source>
        <translation>Sunnuntai</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Monday</source>
        <translation>Maanantai</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tuesday</source>
        <translation>Tiistai</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Wednesday</source>
        <translation>Keskiviikko</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Thursday</source>
        <translation>Torstai</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Friday</source>
        <translation>Perjantai</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saturday</source>
        <translation>Lauantai</translation>
    </message>
    <message>
        <location line="+299"/>
        <source>Port is &lt;b&gt;open&lt;/b&gt;</source>
        <translation>Portti on &lt;b&gt;auki&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Port is &lt;b&gt;closed&lt;/b&gt;</source>
        <translation>Portti on &lt;b&gt;kiinni&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Testing TCP Port…</source>
        <translation>Testataan TCP-porttia…</translation>
    </message>
    <message>
        <location line="+154"/>
        <source>Select &quot;Torrent Done Downloading&quot; Script</source>
        <translation>Valitse &quot;Torrentin lataus valmis&quot; -komentosarja</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="+545"/>
        <source>Incoming Peers</source>
        <translation>Saapuvat vertaiset</translation>
    </message>
    <message>
        <location line="+32"/>
        <location filename="../PrefsDialog.cc" line="+207"/>
        <source>Status unknown</source>
        <translation>Tila tuntematon</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>&amp;Port for incoming connections:</source>
        <translation>&amp;Portti saapuville yhteyksille:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Use UPnP or NAT-PMP port &amp;forwarding from my router</source>
        <translation>Käytä UPnP- tai NAT-PMP-portti&amp;välitystä reitittimeltä</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Options</source>
        <translation>Valinnat</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="-255"/>
        <source> minute(s)</source>
        <extracomment>Spin box suffix, &quot;Stop seeding if idle for: [ 5 minutes ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform>minuutti</numerusform>
            <numerusform>minuuttia</numerusform>
        </translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Select &quot;Torrent Done Seeding&quot; Script</source>
        <translation>Valitse &quot;Torrentin kylvö valmis&quot; -komentosarja</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source> minute(s) ago</source>
        <extracomment>Spin box suffix, &quot;Download is inactive if data sharing stopped: [ 5 minutes ago ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform>minuutti sitten</numerusform>
            <numerusform>minuuttia sitten</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-651"/>
        <source>Automatically add .torrent files &amp;from:</source>
        <translation>Lisää .torrent-tie&amp;dostot automaattisesti kohteesta:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Show the Torrent Options &amp;dialog</source>
        <translation>Näytä torrentin &amp;valintaikkuna</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>&amp;Start added torrents</source>
        <translation>&amp;Käynnistä lisätyt torrentit</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Mo&amp;ve the .torrent file to the trash</source>
        <translation>Sii&amp;rrä .torrent-tiedosto roskakoriin</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Download Queue</source>
        <translation>Latausjono</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Ma&amp;ximum active downloads:</source>
        <translation>Aktiivisia latauksia enint&amp;ään:</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Incomplete</source>
        <translation>Keskeneräinen</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Seeding</source>
        <translation>Kylvätään</translation>
    </message>
    <message>
        <location line="+622"/>
        <source>Remote</source>
        <translation>Etäkäyttö</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="+168"/>
        <source>&lt;i&gt;Blocklist contains %Ln rule(s)&lt;/i&gt;</source>
        <translation>
            <numerusform>&lt;i&gt;Estolista sisältää %Ln säännön&lt;/i&gt;</numerusform>
            <numerusform>&lt;i&gt;Estolista sisältää %Ln sääntöä&lt;/i&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-339"/>
        <source>Pick a &amp;random port every time Transmission is started</source>
        <translation>Valitse &amp;satunnainen portti joka kerta, kun Transmission käynnistetään</translation>
    </message>
    <message>
        <location line="-274"/>
        <source>Limits</source>
        <translation>Rajoitukset</translation>
    </message>
    <message>
        <location line="+321"/>
        <source>Maximum peers per &amp;torrent:</source>
        <translation>Enimmäismäärä vertaisia &amp;torrenttia kohti:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Maximum peers &amp;overall:</source>
        <translation>Enimmäismäärä &amp;vertaisille:</translation>
    </message>
    <message>
        <location line="-193"/>
        <source>Blocklist</source>
        <translation>Estolista</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Enable &amp;automatic updates</source>
        <translation>Ota &amp;automaattiset päivitykset käyttöön</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="-227"/>
        <source>Allow encryption</source>
        <translation>Salli salaus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prefer encryption</source>
        <translation>Suosi salausta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Require encryption</source>
        <translation>Vaadi salaus</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-97"/>
        <source>Privacy</source>
        <translation>Yksityisyys</translation>
    </message>
    <message>
        <location line="-435"/>
        <source>&amp;to</source>
        <translation>&amp;asiakkaalle</translation>
    </message>
    <message>
        <location line="+847"/>
        <location line="+9"/>
        <source>Desktop</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show Transmission icon in the &amp;notification area</source>
        <translation>Näytä Transmissionin kuvake &amp;ilmoitusalueella</translation>
    </message>
    <message>
        <location line="-265"/>
        <source>Te&amp;st Port</source>
        <translation>Te&amp;staa portti</translation>
    </message>
    <message>
        <location line="-101"/>
        <source>Enable &amp;blocklist:</source>
        <translation>Kä&amp;ytä estolistaa:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Update</source>
        <translation>&amp;Päivitä</translation>
    </message>
    <message>
        <location line="-66"/>
        <source>&amp;Encryption mode:</source>
        <translation>&amp;Salaustila:</translation>
    </message>
    <message>
        <location line="+505"/>
        <source>Remote Control</source>
        <translation>Etähallinta</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Allow &amp;remote access</source>
        <translation>&amp;Salli etäkäyttö</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>HTTP &amp;port:</source>
        <translation>HTTP-&amp;portti:</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Only allow these IP a&amp;ddresses:</source>
        <translation>Salli vain seuraavat &amp;IP-osoitteet:</translation>
    </message>
    <message>
        <location line="-1212"/>
        <source>&amp;Upload:</source>
        <translation>L&amp;ähetys:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Download:</source>
        <translation>&amp;Lataus:</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Alternative Speed Limits</source>
        <translation>Vaihtoehtoiset nopeusrajoitukset</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>U&amp;pload:</source>
        <translation>Lä&amp;hetys:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Do&amp;wnload:</source>
        <translation>L&amp;ataus:</translation>
    </message>
    <message>
        <location line="+186"/>
        <source>Reads user clipboard content for torrents</source>
        <translation>Lukee käyttäjän leikepöydän sisältöä uusien torrentien varalta</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Detect new torrents from clipboard</source>
        <translation>Havaitse uudet torrentit leikepöydältä</translation>
    </message>
    <message>
        <location line="+148"/>
        <source>Call scrip&amp;t when downloading is completed:</source>
        <translation>Kutsu skrip&amp;tiä, kun lataus on valmis:</translation>
    </message>
    <message>
        <location line="+105"/>
        <source>Call scrip&amp;t when seeding is completed:</source>
        <translation>Kutsu skrip&amp;tiä, kun kylvö on valmis:</translation>
    </message>
    <message>
        <location line="+342"/>
        <source>µTP is a tool for reducing network congestion.</source>
        <translation>uTP on työkalu, jonka avulla vähennetään verkon ruuhkaa.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Enable µ&amp;TP for peer connections</source>
        <translation>Käytä µ&amp;TP:tä vertaisten yhteyksiin</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Default Public Trackers</source>
        <translation>Oletusarvoiset julkiset seurantapalvelimet</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trackers to use on all public torrents.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;p&gt;To add a backup URL, add it on the next line after a primary URL.&lt;/p&gt;&lt;p&gt;To add a new primary URL, add it after a blank line.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Jäljittimiä kaikkiin julkisiin torrentteihin.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;p&gt;Halutessasi varmuuskopion, lisää se rivillä ensisijaisen URL:n jälkeen.&lt;/p&gt;&lt;p&gt;Halutessasi uuden ensisijaisen URL:n, lisää se tyhjän rivin jälkeen.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Start &amp;minimized in notification area</source>
        <translation>Käynnistä &amp;pienennettynä ilmoitusalueelle</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Notification</source>
        <translation>Ilmoitus</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show a notification when torrents are a&amp;dded</source>
        <translation>Näytä ilmoitus, kun torrent &amp;lisätään</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show a notification when torrents &amp;finish</source>
        <translation>Näytä ilmoitus, kun torrent &amp;valmistuu</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Play a &amp;sound when torrents finish</source>
        <translation>Toista &amp;ääni, kun torrent valmistuu</translation>
    </message>
    <message>
        <location line="-281"/>
        <source>Peer Limits</source>
        <translation>Vertaisten rajoitukset</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Use PE&amp;X to find more peers</source>
        <translation>Käytä &amp;PEX:iä vertaisten löytämiseksi</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>PEX is a tool for exchanging peer lists with the peers you&apos;re connected to.</source>
        <translation>PEX:n avulla voit vaihtaa vertaislistoja jo yhdistettyjen vertaisten kanssa.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;DHT to find more peers</source>
        <translation>Käytä &amp;DHT:tä vertaisten löytämiseksi</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>DHT is a tool for finding peers without a tracker.</source>
        <translation>DHT:n avulla voit löytää vertaisia ilman seurantapalvelinta.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;Local Peer Discovery to find more peers</source>
        <translation>Käytä &amp;paikallisvertaisten etsintää useamman vertaisen löytämiseksi</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>LPD is a tool for finding peers on your local network.</source>
        <translation>LPD etsii vertaisia lähiverkostasi.</translation>
    </message>
    <message>
        <location line="-325"/>
        <source>Encryption</source>
        <translation>Salaus</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+75"/>
        <source>Select Incomplete Directory</source>
        <translation>Valitse keskeneräisten kansio</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Select Watch Directory</source>
        <translation>Valitse tarkkailtava kansio</translation>
    </message>
    <message numerus="yes">
        <location line="-101"/>
        <source>&lt;b&gt;Update succeeded!&lt;/b&gt;&lt;p&gt;Blocklist now has %Ln rule(s).&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;b&gt;Päivitys onnistui!&lt;/b&gt;&lt;p&gt;Estolista sisältää nyt %Ln säännön.&lt;/p&gt;</numerusform>
            <numerusform>&lt;b&gt;Päivitys onnistui!&lt;/b&gt;&lt;p&gt;Estolista sisältää nyt %Ln sääntöä.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;b&gt;Update Blocklist&lt;/b&gt;&lt;p&gt;Getting new blocklist…&lt;/p&gt;</source>
        <translation>&lt;b&gt;Päivitä estolista&lt;/b&gt;&lt;p&gt; Noudetaan uutta estolistaa…&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Select Destination</source>
        <translation>Valitse kohde</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-387"/>
        <source>Adding</source>
        <translation>Lisätään</translation>
    </message>
    <message>
        <location line="+147"/>
        <source>Download is i&amp;nactive if data sharing stopped:</source>
        <extracomment>Please keep this phrase as short as possible, it&apos;s currently the longest and influences dialog width</extracomment>
        <translation>Lataus pysähtyy, jos tietoje&amp;n jakaminen lopetettiin:</translation>
    </message>
    <message>
        <location line="-156"/>
        <source>Downloading</source>
        <translation>Ladataan</translation>
    </message>
    <message>
        <location line="+215"/>
        <source>Append &quot;.&amp;part&quot; to incomplete files&apos; names</source>
        <translation>Lisää &quot;.&amp;part&quot;-pääte keskeneräisten tiedostojen nimiin</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Keep &amp;incomplete files in:</source>
        <translation>Säilytä &amp;keskeneräiset torrentit kansiossa:</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Save to &amp;Location:</source>
        <translation>Tallenna &amp;kohteeseen:</translation>
    </message>
    <message>
        <location line="+282"/>
        <source>Stop seeding at &amp;ratio:</source>
        <translation>Lopeta jakaminen &amp;suhteen ollessa:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Stop seedi&amp;ng if idle for:</source>
        <translation>Pysäytä &amp;jakaminen jos jouten N minuuttia:</translation>
    </message>
    <message>
        <location line="-567"/>
        <source>Transmission Preferences</source>
        <translation>Transmissionin asetukset</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Speed</source>
        <translation>Nopeus</translation>
    </message>
    <message>
        <location line="+735"/>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+116"/>
        <source>Not supported by remote sessions</source>
        <translation>Ei tuettu etäistunnoissa</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../Application.cc" line="-313"/>
        <source>Invalid option</source>
        <translation>Epäkelpo valinta</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Start Now</source>
        <translation>Aloita nyt</translation>
    </message>
</context>
<context>
    <name>RelocateDialog</name>
    <message>
        <location filename="../RelocateDialog.cc" line="+65"/>
        <source>Select Location</source>
        <translation>Valitse sijainti</translation>
    </message>
    <message>
        <location filename="../RelocateDialog.ui" line="+14"/>
        <source>Set Torrent Location</source>
        <translation>Aseta torrentin sijainti</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Set Location</source>
        <translation>Aseta sijainti</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>New &amp;location:</source>
        <translation>Uusi &amp;sijainti:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Move from the current folder</source>
        <translation>&amp;Siirrä tämänhetkisestä hakemistosta</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Local data is &amp;already there</source>
        <translation>Paikallinen data on &amp;jo siellä</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../Session.cc" line="+505"/>
        <source>Error Renaming Path</source>
        <translation>Virhe uudelleennimettäessä polkua</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;p&gt;&lt;b&gt;Unable to rename &quot;%1&quot; as &quot;%2&quot;: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please correct the errors and try again.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Kohdetta &quot;%1&quot; ei voi nimetä nimellä &quot;%2&quot;: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Korjaa virheet ja yritä uudelleen.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+528"/>
        <source>Error Adding Torrent</source>
        <translation>Virhe lisättäessä torrentia</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>%1 (copy of %2)</source>
        <translation>%1 (kopio %2)</translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source>Duplicate Torrent(s)</source>
        <translation>
            <numerusform>Torrentin kaksoiskappale</numerusform>
            <numerusform>Torrentien kaksoiskappaleita</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+2"/>
        <source>Unable to add %n duplicate torrent(s)</source>
        <translation>
            <numerusform>%n torrentin kaksoiskappaletta ei voitu lisätä</numerusform>
            <numerusform>%n torrentien kaksoiskappaletta ei voitu lisätä</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <location filename="../SessionDialog.ui" line="+14"/>
        <source>Change Session</source>
        <translation>Vaihda istuntoa</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Source</source>
        <translation>Lähde</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Start &amp;Local Session</source>
        <translation>Aloita &amp;paikallinen istunto</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Connect to &amp;Remote Session</source>
        <translation>Yhdistä &amp;etäistuntoon</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Host:</source>
        <translation>&amp;Isäntä:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Port:</source>
        <translation>&amp;Portti:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Authentication required</source>
        <translation>&amp;Tunnistautuminen vaaditaan</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Username:</source>
        <translation>&amp;Käyttäjänimi:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>Sala&amp;sana:</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <location filename="../StatsDialog.ui" line="+14"/>
        <source>Statistics</source>
        <translation>Tilastotiedot</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Current Session</source>
        <translation>Tämänhetkinen istunto</translation>
    </message>
    <message>
        <location line="+12"/>
        <location line="+96"/>
        <source>Uploaded:</source>
        <translation>Lähetetty:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Downloaded:</source>
        <translation>Ladattu:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Ratio:</source>
        <translation>Suhde:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Duration:</source>
        <translation>Kesto</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Total</source>
        <translation>Kaikkiaan</translation>
    </message>
    <message numerus="yes">
        <location filename="../StatsDialog.cc" line="+63"/>
        <source>Started %Ln time(s)</source>
        <translation>
            <numerusform>Käynnistetty %Ln kerran</numerusform>
            <numerusform>Käynnistetty %Ln kertaa</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Torrent</name>
    <message>
        <location filename="../Torrent.cc" line="+323"/>
        <source>Verifying local data</source>
        <translation>Vahvistetaan paikallista dataa</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Downloading</source>
        <translation>Ladataan</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Seeding</source>
        <translation>Kylvätään</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Finished</source>
        <translation>Valmistunut</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paused</source>
        <translation>Tauotettu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Queued for verification</source>
        <translation>Laitettiin jonoon tarkistusta varten</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for download</source>
        <translation>Laitettiin jonoon latausta varten</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for seeding</source>
        <translation>Laitettiin jonoon jakamista varten</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Tracker gave a warning: %1</source>
        <translation>Seurantapalvelin antoi varoituksen: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tracker gave an error: %1</source>
        <translation>Seurantapalvelin antoi virheen: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Error: %1</source>
        <translation>Virhe: %1</translation>
    </message>
</context>
<context>
    <name>TorrentDelegate</name>
    <message>
        <location filename="../TorrentDelegate.cc" line="+174"/>
        <source>Magnetized transfer - retrieving metadata (%1%)</source>
        <extracomment>First part of torrent progress string, %1 is the percentage of torrent metadata downloaded</extracomment>
        <translation>Magnetisoitu siirto - noudetaan metadataa (%1 %)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is how much we&apos;ll have when done, %3 is a percentage of the two</extracomment>
        <translation>%1 / %2 (%3%)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5 Goal: %6)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio, %6 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1/%2 (%3 %), lähetetty %4 (Jakosuhde: %5 Tavoite: %6)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio</extracomment>
        <translation>%1/%2 (%3 %), lähetetty %4 (Jakosuhde: %5)</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>%1, uploaded %2 (Ratio: %3 Goal: %4)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio, %4 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1, lähetetty %2 (Jakosuhde: %3 Tavoite: %4)</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>%1, uploaded %2 (Ratio: %3)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio</extracomment>
        <translation>%1, lähetetty %2 (Suhde: %3)</translation>
    </message>
    <message>
        <location line="+15"/>
        <source> - %1 left</source>
        <extracomment>Second (optional) part of torrent progress string, %1 is duration, notice that leading space (before the dash) is included here</extracomment>
        <translation>- %1 jäljellä</translation>
    </message>
    <message>
        <location line="+6"/>
        <source> - Remaining time unknown</source>
        <extracomment>Second (optional) part of torrent progress string, notice that leading space (before the dash) is included here</extracomment>
        <translation> - Jäljellä oleva aika tuntematon </translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Ratio: %1</source>
        <translation>Jakosuhde: %1</translation>
    </message>
    <message numerus="yes">
        <location line="+44"/>
        <source>Downloading from %Ln peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Ladataan %Ln vertaiselta</numerusform>
            <numerusform>Ladataan %Ln vertaiselta</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+22"/>
        <source>Seeding to %Ln peer(s)</source>
        <translation>
            <numerusform>Jaetaan %Ln vertaiselle</numerusform>
            <numerusform>Jaetaan %Ln vertaiselle</numerusform>
        </translation>
    </message>
    <message>
        <location line="+18"/>
        <source> - </source>
        <translation> - </translation>
    </message>
    <message numerus="yes">
        <location line="-50"/>
        <source>Downloading metadata from %Ln peer(s) (%1% done)</source>
        <translation>
            <numerusform>Ladataan metadataa %Ln vertaiselta (%1 % valmiina)</numerusform>
            <numerusform>Ladataan metadataa %Ln vertaiselta (%1 % valmiina)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+15"/>
        <source>Downloading from %1 of %Ln connected peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Ladataan %1 /%Ln yhdistetyltä vertaiselta</numerusform>
            <numerusform>Ladataan %1/%Ln yhdistetyltä vertaiselta</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+8"/>
        <source> and %Ln web seed(s)</source>
        <extracomment>Second (optional) part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;, notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform>ja %Ln verkkolähteet</numerusform>
            <numerusform> ja %Ln verkkolähteet</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+13"/>
        <source>Seeding to %1 of %Ln connected peer(s)</source>
        <translation>
            <numerusform>Lähteet %1 / %Ln yhdistetyt vertaiskoneet</numerusform>
            <numerusform>Seeding to %1 of %Ln connected peers</numerusform>
        </translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Verifying local data (%1% tested)</source>
        <translation>Vahvistetaan paikallista daataa (%1% testattu)</translation>
    </message>
</context>
<context>
    <name>TrackerDelegate</name>
    <message numerus="yes">
        <location filename="../TrackerDelegate.cc" line="+216"/>
        <source>Got a list of%1 %Ln peer(s)%2 %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>
            <numerusform>Sai luettelon%1 %Ln vertaiskoneista%2 %3 sitten</numerusform>
            <numerusform>Got a list of%1 %Ln peers%2 %3 ago</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer list request %1timed out%2 %3 ago; will retry</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>Vertaiskoneiden luettelo %1aikakatkaistu%2 %3 sitten; yrittää uudelleen</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Got an error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>Vastaanotettiin virhe %1&quot;%2&quot;%3 %4 sitten</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>No updates scheduled</source>
        <translation>Ei aikataulutettuja päivityksiä</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Asking for more peers in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Kysytään lisää vertaisia %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for more peers</source>
        <translation>Laitettu jonoon lisävertaisten kysymistä varten</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Asking for peer counts now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Kysytään vertaisten lukumäärää nyt… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="-40"/>
        <source>Tracker had%1 %Ln seeder(s)%2</source>
        <extracomment>First part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup</extracomment>
        <translation>
            <numerusform>Surantapalvelimella on%1 %Ln jakajaa%2</numerusform>
            <numerusform>Surantapalvelimella on%1 %Ln jakajaa%2</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source> and%1 %Ln leecher(s)%2 %3 ago</source>
        <extracomment>Second part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup, %3 is duration; notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform>ja%1 %Ln lataajia%2 %3 sitten</numerusform>
            <numerusform> ja%1 %Ln lataajia%2 %3 sitten</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tracker had %1no information%2 on peer counts %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>Seurantapalvelimella %1ei ollut tietoa%2 jakajien määrästä %3 sitten</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>Got a scrape error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>Sai tähtäinvirheen %1&quot;%2&quot;%3 %4 sitten</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Asking for more peers now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Pyydetään lisää vertaisia nyt… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Asking for peer counts in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Vertaismäärien pyytäminen %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for peer counts</source>
        <translation>Jonossa vertaismäärien pyytämiseksi</translation>
    </message>
</context>
<context>
    <name>TrackersDialog</name>
    <message>
        <location filename="../TrackersDialog.ui" line="+17"/>
        <source>Edit Trackers</source>
        <translation>Muokkaa seurantapalvelimia</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Tracker Announce URLs</source>
        <translation>Jäljitin Ilmoittaa URL-osoitteet</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>To add a new primary URL, add it after a blank line.</source>
        <translation>Jos haluat lisätä uuden ensisijaisen URL:n, lisää se tyhjän rivin jälkeen.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To add a backup URL, add it on the next line after a primary URL.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Jos haluat varmuuskopion URL:n, lisää se seuraavalla rivillä ensisijaisen URL:n jälkeen.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Also see Default Public Trackers in Edit &gt; Preferences &gt; Network</source>
        <translation>Katso myös julkisten jäljittimien oletusarvot Muokkaa &gt; Asetukset &gt; Verkko</translation>
    </message>
</context>
</TS>
